## ----PDF, eval=FALSE-----------------------------------------------------
#  RNAseqNetUsersGuide()

## ----Rmd, eval=FALSE-----------------------------------------------------
#  RNAseqNetUsersGuide(html = FALSE)

## ----sessionInfo---------------------------------------------------------
sessionInfo()

